<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="41"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Πρόσθετο βίντεο FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="45"/>
        <source>Video Files</source>
        <translation>Αρχεία βίντεο</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="191"/>
        <source>About FFVideo Plugin</source>
        <translation>Περί του πρόσθετου FFVideo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="192"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Πρόσθετο βίντεο FFmpeg για το Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="193"/>
        <source>Compiled against:</source>
        <translation>Μεταγλωττίστηκε χρησιμοποιώντας:</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="202"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Ρυθμός bit</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Ρυθμός bit ήχου</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Ρυθμός δειγματοληψίας ήχου</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="86"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="73"/>
        <location filename="../ffvideometadatamodel.cpp" line="75"/>
        <source>Audio channels</source>
        <translation>Κανάλια ήχου</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Audio format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="85"/>
        <source>Video size</source>
        <translation>Μέγεθος βίντεο</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="86"/>
        <source>Video bitrate</source>
        <translation>Ρυθμός bit βίντεο</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="89"/>
        <source>Video format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>Βίντεο FFmpeg</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <location filename="../videowindow.cpp" line="51"/>
        <location filename="../videowindow.cpp" line="70"/>
        <source>&amp;Pause</source>
        <translation>&amp;Παύση</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <location filename="../videowindow.cpp" line="51"/>
        <source>Space</source>
        <translation>Διάστημα</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="47"/>
        <location filename="../videowindow.cpp" line="52"/>
        <source>&amp;Stop</source>
        <translation>&amp;Διακοπή</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="47"/>
        <location filename="../videowindow.cpp" line="52"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="49"/>
        <location filename="../videowindow.cpp" line="54"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Πλήρης οθόνη</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="49"/>
        <location filename="../videowindow.cpp" line="54"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="75"/>
        <source>&amp;Resume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="80"/>
        <source>&amp;Play</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
